Depth class

Model class for Depth class

Constructors

Depth({num? quantity, num? price, num? orders})
Depth.fromJson(dynamic json)
Used to decode Depth json

Properties

hashCode int
The hash code for this object.
no setterinherited
orders num?
no setter
price num?
no setter
quantity num?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({num? quantity, num? price, num? orders}) Depth
Clone new Depth object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setOrders(int int) → void
Setter for order
setPrice(double d) → void
Setter for price
setQuantity(int int) → void
Setter for quantity
toJson() Map<String, dynamic>
Encode Depth json
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited